aboutsummaryrefslogtreecommitdiff
path: root/libstorycode/slide_render_cairo.h
diff options
context:
space:
mode:
Diffstat (limited to 'libstorycode/slide_render_cairo.h')
-rw-r--r--libstorycode/slide_render_cairo.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/libstorycode/slide_render_cairo.h b/libstorycode/slide_render_cairo.h
index 6589945..9587007 100644
--- a/libstorycode/slide_render_cairo.h
+++ b/libstorycode/slide_render_cairo.h
@@ -33,7 +33,8 @@
struct slide_pos
{
int para; /* Paragraph number (corresponding to narrative items) */
- int pos; /* Byte position within paragraph (yes, really) */
+ int run; /* Run number */
+ int pos; /* Byte position within run (yes, really) */
int trail; /* 1 = end of character, 0 = before */
};